@@ -1,18 +1,14 @@
-use std::fmt::Display;
 use std::fs::File;
 use std::io::{self, Read};
-use std::result;
-
-use semver_parser::range::{Op, VersionReq};
-use semver_parser::version::Version;
 
 /// The common result type, our errors will be simple strings.
-pub type Result<T> = result::Result<T, String>;
+pub type Result<T> = std::result::Result<T, String>;
 
+#[cfg(any(feature = "html_root_url_updated", feature = "markdown_deps_updated"))]
 fn join<T>(iter: T, sep: &str) -> String
 where
     T: IntoIterator,
-    T::Item: Display,
+    T::Item: std::fmt::Display,
 {
     let mut buf = String::new();
     let mut iter = iter.into_iter();
@@ -41,12 +37,18 @@ pub fn read_file(path: &str) -> io::Result<String> {
 }
 
 /// Indent every line in text by four spaces.
+#[cfg(any(feature = "html_root_url_updated", feature = "markdown_deps_updated"))]
 pub fn indent(text: &str) -> String {
     join(text.lines().map(|line| String::from("    ") + line), "\n")
 }
 
 /// Verify that the version range request matches the given version.
-pub fn version_matches_request(version: &Version, request: &VersionReq) -> Result<()> {
+#[cfg(any(feature = "html_root_url_updated", feature = "markdown_deps_updated"))]
+pub fn version_matches_request(
+    version: &semver_parser::version::Version,
+    request: &semver_parser::range::VersionReq,
+) -> Result<()> {
+    use semver_parser::range::Op;
     if request.predicates.len() != 1 {
         // Can only handle simple dependencies
         return Ok(());
@@ -93,11 +95,15 @@ pub fn version_matches_request(version: &Version, request: &VersionReq) -> Resul
 
 #[cfg(test)]
 mod tests {
+    #[cfg(any(feature = "html_root_url_updated", feature = "markdown_deps_updated"))]
     use semver_parser::range::parse as parse_request;
+    #[cfg(any(feature = "html_root_url_updated", feature = "markdown_deps_updated"))]
     use semver_parser::version::parse as parse_version;
 
+    #[cfg(any(feature = "html_root_url_updated", feature = "markdown_deps_updated"))]
     use super::*;
 
+    #[cfg(any(feature = "html_root_url_updated", feature = "markdown_deps_updated"))]
     mod test_version_matches_request {
         use super::*;
 
