@@ -1,6 +1,8 @@
 //! `version-sync` provides macros for keeping version numbers in sync
 //! with your crate version.
 //!
+//! # Library Overview
+//!
 //! When making a release of a Rust project, you typically need to
 //! adjust some version numbers in your code and documentation. This
 //! crate gives you macros that covers some typical cases where
@@ -10,11 +12,15 @@
 //!   dependency on your crate. See [`assert_markdown_deps_updated`].
 //!
 //! * A `Changelog.md` file that should at least mention the current
-//!   version. See [`assert_contains_regex`].
+//!   version. See [`assert_contains_regex`] and
+//!   [`assert_contains_substring`].
 //!
 //! * The [`html_root_url`] attribute that tells other crates where to
 //!   find your documentation. See [`assert_html_root_url_updated`].
 //!
+//! Except for [`assert_contains_substring`], the macros are gated
+//! behind individual features, as detailed below.
+//!
 //! A typical configuration will use an integration test to verify
 //! that all version numbers are in sync. Create a
 //! `tests/version-numbers.rs` file with:
@@ -22,18 +28,29 @@
 //! ```rust
 //! #[test]
 //! # fn fake_hidden_test_case_1() {}
-//! fn test_readme_deps() {
+//! # #[cfg(feature = "markdown_deps_updated")]
+//! fn test_readme_deps_updated() {
 //!     version_sync::assert_markdown_deps_updated!("README.md");
 //! }
 //!
 //! #[test]
 //! # fn fake_hidden_test_case_2() {}
+//! fn test_readme_mentions_version() {
+//!     version_sync::assert_contains_substring!("README.md", "Version {version}");
+//! }
+//!
+//! #[test]
+//! # fn fake_hidden_test_case_3() {}
+//! # #[cfg(feature = "html_root_url_updated")]
 //! fn test_html_root_url() {
 //!     version_sync::assert_html_root_url_updated!("src/lib.rs");
 //! }
 //!
 //! # fn main() {
-//! #     test_readme_deps();
+//! #     #[cfg(feature = "markdown_deps_updated")]
+//! #     test_readme_deps_updated();
+//! #     test_readme_mentions_version();
+//! #     #[cfg(feature = "html_root_url_updated")]
 //! #     test_html_root_url();
 //! # }
 //! ```
@@ -41,21 +58,38 @@
 //! When you run `cargo test`, your version numbers will be
 //! automatically checked.
 //!
+//! # Cargo Features
+//!
+//! In case you only need some of the macros above, you can disable
+//! them individually using Cargo features. The features are:
+//!
+//! * `markdown_deps_updated` enables [`assert_markdown_deps_updated`].
+//! * `html_root_url_updated` enables [`assert_html_root_url_updated`].
+//! * `contains_regex` enables [`assert_contains_regex`].
+//!
+//! All of these features are enabled by default.
+//!
 //! [`html_root_url`]: https://rust-lang-nursery.github.io/api-guidelines/documentation.html#crate-sets-html_root_url-attribute-c-html-root
 //! [`assert_markdown_deps_updated`]: macro.assert_markdown_deps_updated.html
 //! [`assert_html_root_url_updated`]: macro.assert_html_root_url_updated.html
 //! [`assert_contains_regex`]: macro.assert_contains_regex.html
 
-#![doc(html_root_url = "https://docs.rs/version-sync/0.9.2")]
+#![doc(html_root_url = "https://docs.rs/version-sync/0.9.3")]
+#![forbid(unsafe_code)]
 #![deny(missing_docs)]
 
 mod contains_regex;
+mod contains_substring;
 mod helpers;
 mod html_root_url;
 mod markdown_deps;
 
+#[cfg(feature = "contains_regex")]
 pub use crate::contains_regex::check_contains_regex;
+pub use crate::contains_substring::check_contains_substring;
+#[cfg(feature = "html_root_url_updated")]
 pub use crate::html_root_url::check_html_root_url;
+#[cfg(feature = "markdown_deps_updated")]
 pub use crate::markdown_deps::check_markdown_deps;
 
 /// Assert that dependencies on the current package are up to date.
@@ -68,6 +102,8 @@ pub use crate::markdown_deps::check_markdown_deps;
 /// variables are automatically set by Cargo when compiling your
 /// crate.
 ///
+/// This macro is enabled by the `markdown_deps_updated` feature.
+///
 /// # Usage
 ///
 /// The typical way to use this macro is from an integration test:
@@ -92,9 +128,8 @@ pub use crate::markdown_deps::check_markdown_deps;
 /// # Panics
 ///
 /// If any TOML code block fails the check, `panic!` will be invoked.
-///
-/// [`check_markdown_deps`]: fn.check_markdown_deps.html
 #[macro_export]
+#[cfg(feature = "markdown_deps_updated")]
 macro_rules! assert_markdown_deps_updated {
     ($path:expr) => {
         let pkg_name = env!("CARGO_PKG_NAME");
@@ -119,6 +154,8 @@ macro_rules! assert_markdown_deps_updated {
 /// `$CARGO_PKG_VERSION`. These environment variables are
 /// automatically set by Cargo when compiling your crate.
 ///
+/// This macro is enabled by the `html_root_url_updated` feature.
+///
 /// # Usage
 ///
 /// The typical way to use this macro is from an integration test:
@@ -145,8 +182,8 @@ macro_rules! assert_markdown_deps_updated {
 /// If the `html_root_url` fails the check, `panic!` will be invoked.
 ///
 /// [api-guidelines]: https://rust-lang-nursery.github.io/api-guidelines/documentation.html#crate-sets-html_root_url-attribute-c-html-root
-/// [`check_html_root_url`]: fn.check_html_root_url.html
 #[macro_export]
+#[cfg(feature = "html_root_url_updated")]
 macro_rules! assert_html_root_url_updated {
     ($path:expr) => {
         let pkg_name = env!("CARGO_PKG_NAME");
@@ -157,12 +194,77 @@ macro_rules! assert_html_root_url_updated {
     };
 }
 
+/// Assert that versions numbers are up to date via substring matching.
+///
+/// This macro allows you verify that the current version number is
+/// mentioned in a particular file, such as a changelog file. You do
+/// this by specifying a template which will be matched against the
+/// content of the file.
+///
+/// The macro calls [`check_contains_substring`] on the file name
+/// given. The package name and current package version is
+/// automatically taken from the `$CARGO_PKG_NAME` and
+/// `$CARGO_PKG_VERSION` environment variables. These environment
+/// variables are automatically set by Cargo when compiling your
+/// crate.
+///
+/// # Usage
+///
+/// The typical way to use this macro is from an integration test:
+///
+/// ```rust
+/// #[test]
+/// # fn fake_hidden_test_case() {}
+/// # // The above function ensures test_readme_mentions_version is
+/// # // compiled.
+/// fn test_readme_mentions_version() {
+///     version_sync::assert_contains_substring!("README.md", "### Version {version}");
+/// }
+///
+/// # fn main() {
+/// #     test_readme_mentions_version();
+/// # }
+/// ```
+///
+/// Tests are run with the current directory set to directory where
+/// your `Cargo.toml` file is, so this will find a `README.md` file
+/// next to your `Cargo.toml` file. It will then check that there is a
+/// heading mentioning the current version of your crate.
+///
+/// The template can contain placeholders which are replaced before
+/// the search begins:
+///
+/// * `{version}`: the current version number of your package.
+/// * `{name}`: the name of your package.
+///
+/// This way you can search for things like `"Latest version of {name}
+/// is: {version}"` and make sure you update your READMEs and
+/// changelogs consistently.
+///
+/// See [`assert_contains_regex`] if you want to search for a regular
+/// expression instead.
+///
+/// # Panics
+///
+/// If the substring cannot be found, `panic!` will be invoked and
+/// your integration test will fail.
+#[macro_export]
+macro_rules! assert_contains_substring {
+    ($path:expr, $format:expr) => {
+        let pkg_name = env!("CARGO_PKG_NAME");
+        let pkg_version = env!("CARGO_PKG_VERSION");
+        if let Err(err) = $crate::check_contains_substring($path, $format, pkg_name, pkg_version) {
+            panic!("{}", err);
+        }
+    };
+}
+
 /// Assert that versions numbers are up to date via a regex.
 ///
 /// This macro allows you verify that the current version number is
 /// mentioned in a particular file, such as a changelog file. You do
 /// this by specifying a regular expression which will be matched
-/// against the file.
+/// against the contents of the file.
 ///
 /// The macro calls [`check_contains_regex`] on the file name given.
 /// The package name and current package version is automatically
@@ -170,6 +272,8 @@ macro_rules! assert_html_root_url_updated {
 /// environment variables. These environment variables are
 /// automatically set by Cargo when compiling your crate.
 ///
+/// This macro is enabled by the `contains_regex` feature.
+///
 /// # Usage
 ///
 /// The typical way to use this macro is from an integration test:
@@ -207,9 +311,8 @@ macro_rules! assert_html_root_url_updated {
 ///
 /// If the regular expression cannot be found, `panic!` will be
 /// invoked and your integration test will fail.
-///
-/// [`check_contains_regex`]: fn.check_contains_regex.html
 #[macro_export]
+#[cfg(feature = "contains_regex")]
 macro_rules! assert_contains_regex {
     ($path:expr, $format:expr) => {
         let pkg_name = env!("CARGO_PKG_NAME");
