@@ -1,9 +1,11 @@
 #[test]
+#[cfg(feature = "markdown_deps_updated")]
 fn test_readme_deps() {
     version_sync::assert_markdown_deps_updated!("README.md");
 }
 
 #[test]
+#[cfg(feature = "contains_regex")]
 fn test_readme_changelog() {
     version_sync::assert_contains_regex!(
         "README.md",
@@ -12,6 +14,7 @@ fn test_readme_changelog() {
 }
 
 #[test]
+#[cfg(feature = "html_root_url_updated")]
 fn test_html_root_url() {
     version_sync::assert_html_root_url_updated!("src/lib.rs");
 }
